# megastep
[![Documentation Status](https://readthedocs.org/projects/ansicolortags/badge/?version=latest)](https://andyljones.com/megastep)
[![Gitter](https://img.shields.io/gitter/room/andyljones/megastep)](https://gitter.im/megastep-rl/community)

**megastep** helps you build 1-million FPS reinforcement learning environments with a single consumer GPU.

[Docs, tutorials and more are available on the project homepage](https://andyljones.com/megastep).